@@ -120,14 +120,16 @@ class GraphWrapQuery:
             edgeInfo={}
             tailInfo={}
         
-        if "direct" not in edgeInfo:
+        if "direct" not in edgeInfo and len(edgeInfo)>0:
             edgeInfo["direct"]=""
         
         singleYieldDict={}
         if len(singleYieldList)>0:
             for nodeTypeAttrItem in singleYieldList:
+                if type(nodeTypeAttrItem["nodeAttr"])==str:
+                    nodeTypeAttrItem["nodeAttr"]=nodeTypeAttrItem["nodeAttr"].strip()
                 singleYieldDict[nodeTypeAttrItem["nodeType"]]=singleYieldDict.get(nodeTypeAttrItem["nodeType"],[])+[nodeTypeAttrItem["nodeAttr"]]
-        
+            
         # LOOKUP语句构建
         if head==True:  
             singleQueryStrList=["LOOKUP ON {nodeType} WHERE {nodeType}.{nodeIdAttr}=='{nodeIdVal}'|\
