@@ -14,6 +14,7 @@ from string import punctuation
 import argparse
 from string import punctuation
 import re
+import shutil
 
 def wrapNebula2Df(nebulaObj):
     '''将platoDB查询到的对象转为df'''
@@ -126,19 +127,19 @@ def existTag(nodeType,nodeIdAttr,nodeName,gClient):
             passTag+=1
     return False
 
-def transferBetweenPlato(srcGHost,srcGPort,srcGUser,srcGPassword,srcGdbName,
-                         tgtGHost,tgtGPort,tgtGUser,tgtGPassword,tgtGdbName,tgtGAPIUrl,edgeTypeList=[],
+def transferBetweenPlato(gHost,gPort,gUser,gPassword,
+                         srcGdbName,tgtGdbName,tgtGAPIUrl,edgeTypeList=[],
                          srcVertexKeynameDict={"srcNodeType":"srcNodeIdAttr"},csv2platoDTypeDict={"srcNodeIdAttr":"string"},
                          batchSize=64,projectName="",platoAPIIP="",platoAPIPort=8083):
     
-    srcConnection_pool = ConnectionPool(srcGHost, srcGPort,network_timeout=300000)
+    srcConnection_pool = ConnectionPool(gHost, gPort,network_timeout=300000)
     srcClient = GraphClient(srcConnection_pool)
-    srcClient.authenticate(srcGUser, srcGPassword)
+    srcClient.authenticate(gUser, gPassword)
     srcClient.execute_query("use {}".format(srcGdbName))
 
-    tgtConnection_pool = ConnectionPool(tgtGHost, tgtGPort,network_timeout=300000)
+    tgtConnection_pool = ConnectionPool(gHost, gPort,network_timeout=300000)
     tgtClient = GraphClient(tgtConnection_pool)
-    tgtClient.authenticate(tgtGUser, tgtGPassword)
+    tgtClient.authenticate(gUser, gPassword)
     tgtClient.execute_query("use {}".format(tgtGdbName))
 
     # 1.构建data的项目
@@ -162,15 +163,19 @@ def transferBetweenPlato(srcGHost,srcGPort,srcGUser,srcGPassword,srcGdbName,
     # 构建schema
     for srcVertexTypeAttrSetItem in srcVertexTypeAttrSetDict:
         srcVertexTypeSet=srcVertexTypeAttrSetDict[srcVertexTypeAttrSetItem]
-        tagAttrStr=",".join(["{} {}".format(srcVertexTypeItem,srcVertexTypeSet[srcVertexTypeItem] if srcVertexTypeSet[srcVertexTypeItem] not in ["int","double"] else srcVertexTypeSet[srcVertexTypeItem]+" DEFAULT 0") for srcVertexTypeItem in srcVertexTypeSet])
+        attrList=["{} {}".format(srcVertexTypeItem,srcVertexTypeSet[srcVertexTypeItem] if srcVertexTypeSet[srcVertexTypeItem] not in ["int","double"] else srcVertexTypeSet[srcVertexTypeItem]+" DEFAULT 0") for srcVertexTypeItem in srcVertexTypeSet]
+        attrList.append("from_kb string")
+        tagAttrStr=",".join(attrList)
         buildTagSchemaStr="CREATE TAG IF NOT EXISTS {}({}) ".format(srcVertexTypeAttrSetItem,tagAttrStr)
         tgtClient.execute_query(buildTagSchemaStr)
 
     
     for srcEdgeTypeAttrSetItem in srcEdgeTypeAttrSetDict:
         srcEdgeTypeSet=srcEdgeTypeAttrSetDict[srcEdgeTypeAttrSetItem]
-        tagAttrStr=",".join(["{} {}".format(srcEdgeTypeItem,srcEdgeTypeSet[srcEdgeTypeItem]) for srcEdgeTypeItem in srcEdgeTypeSet])
-        buildEdgeSchemaStr="CREATE EDGE IF NOT EXISTS {}({}) ".format(srcEdgeTypeAttrSetItem,tagAttrStr)
+        attrList=["{} {}".format(srcEdgeTypeItem,srcEdgeTypeSet[srcEdgeTypeItem]) for srcEdgeTypeItem in srcEdgeTypeSet]
+        attrList.append("from_kb string")
+        edgeAttrStr=",".join(attrList)
+        buildEdgeSchemaStr="CREATE EDGE IF NOT EXISTS {}({}) ".format(srcEdgeTypeAttrSetItem,edgeAttrStr)
         tgtClient.execute_query(buildEdgeSchemaStr)
 
     # 构建index
@@ -217,6 +222,7 @@ def transferBetweenPlato(srcGHost,srcGPort,srcGUser,srcGPassword,srcGdbName,
             vertexInfoDf.rename(columnRenameDict,axis=1,inplace=True)
             vertexInfoDf.drop("VertexID",axis=1,inplace=True)
             vertexInfoDf["{}SysId".format(srcVertexTypeItem)]=vertexInfoDf["{}".format(srcVertexKeynameDict[srcVertexTypeItem])].apply(lambda row:"{}".format(srcVertexTypeItem)+"_"+row)
+            vertexInfoDf["from_kb"]=srcGdbName
             if batchI==0:
                 vertexInfoDf.to_csv("csv2plato/{}/{}Node-fornew.csv".format(projectName,srcVertexTypeItem),index=None)
             else:
@@ -250,6 +256,7 @@ def transferBetweenPlato(srcGHost,srcGPort,srcGUser,srcGPassword,srcGdbName,
                         tailKeyname=srcVertexKeynameDict[tgtVertexTypeItem],
                         attrList=attrListStr
                     )))
+                    goDf["from_kb"]=srcGdbName
                     goDf.replace("",np.nan,inplace=True)
                     goDf.dropna(inplace=True)
                     if goDf.shape[0]>0:
@@ -286,28 +293,36 @@ def transferBetweenPlato(srcGHost,srcGPort,srcGUser,srcGPassword,srcGdbName,
         json.dump(rawSchemaJson,rawSchemaJsonFile)
 
     fileList=[]
+    closedFileList=[]
     for fileItem in tqdm.tqdm(os.listdir("csv2plato/"+projectName)):
+        uploadedFile=open("csv2plato/"+projectName+"/"+fileItem,'rb')
         if fileItem.split(".")[1]=="csv":
-            fileList.append(("csv",(fileItem,open("csv2plato/"+projectName+"/"+fileItem,'rb'),"test/csv")))
+            fileList.append(("csv",(fileItem,uploadedFile,"test/csv")))
         if fileItem.split(".")[1]=="json":
-            fileList.append(("json",(fileItem,open("csv2plato/"+projectName+"/"+fileItem,'rb'),"application/json")))
+            fileList.append(("json",(fileItem,uploadedFile,"application/json")))
+        closedFileList.append(uploadedFile)
 
     tgtGAPIUrl=tgtGAPIUrl
     fileServerUrl="{}/csv2platodb/upload".format(tgtGAPIUrl)
     response = requests.request("POST", fileServerUrl, files=fileList)
+    
+    for fileItem in closedFileList:
+        fileItem.close()
+    shutil.rmtree("csv2plato/"+projectName)
         
     print(response.text)
     return response
 
-def existEdge(headType,headIdAttr,headIdVal,tailType,tailIdAttr,tailIdVal,edgeType,gClient):
+def existEdge(headType,headIdAttr,headIdVal,tailType,tailIdAttr,tailIdVal,edgeType,edgeDir,gClient):
     '''查看头节点为headIdVal，尾节点为tailIdVal的edgeType边是否存在（gClient提前设定好图数据库）'''
     searchEdgeDf=wrapNebula2Df(gClient.execute_query("LOOKUP ON {headType} WHERE {headType}.{headIdAttr}=='{headIdVal}'|\
-                                                        GO FROM $-.VertexID OVER {edgeType} WHERE  $$.{tailType}.{tailIdAttr}=='{tailIdVal}'|LIMIT 1\
+                                                        GO FROM $-.VertexID OVER {edgeType} {edgeDir} WHERE  $$.{tailType}.{tailIdAttr}=='{tailIdVal}'|LIMIT 1\
                                                             YIELD $$.{tailType}.{tailIdAttr}".format(
                                                                                                 headType=headType,
                                                                                                 headIdAttr=headIdAttr,
                                                                                                 headIdVal=headIdVal,
                                                                                                 edgeType=edgeType,
+                                                                                                edgeDir=edgeDir,
                                                                                                 tailType=tailType,
                                                                                                 tailIdAttr=tailIdAttr,
                                                                                                 tailIdVal=tailIdVal
@@ -412,18 +427,40 @@ def addTokenForEntities(gClient,gDBName,nodeIdAttrList,tabuList=[],projectName="
     print("本地文件生成")
     return VESchema
 
+def ucreateGDB(gClient,gdbname):
+    gClient.execute_query("CREATE SPACE {}".format(gdbname))
+    
+def ucreateTag(gClient,tagAttrTypeDefaultDict,defaultTagAttrTypeDict={"Alias":{"Name":{"type":"string","default":"null"},
+                                                                                "checked":{"type":"string","default":"false"},
+                                                                                "from_kg":{"type":"string","default":""}}}):
+    for tagTypeItem in tagAttrTypeDefaultDict:
+        attrList=["{} {} DEFAULT {}".format(attrNameKeyItem,
+                                                tagAttrTypeDefaultDict[attrNameKeyItem]["type"],
+                                                tagAttrTypeDefaultDict[attrNameKeyItem]["default"]) for attrNameKeyItem in tagAttrTypeDefaultDict[tagTypeItem]]
+        attrListStr=",".join(attrList)
+        gClient.execute_query("CREATE TAG IF NOT EXISTS {} ({})".format(tagTypeItem,attrListStr))
+
+def ucreateEdge(gClient,edgeAttrTypeDefaultDict,defaultEdgeAttrTypeDict={"alias":{"checked":{"type":"string","default":"false"},
+                                                                                "from_kg":{"type":"string","default":""}}}):
+    for tagTypeItem in edgeAttrTypeDefaultDict:
+        attrList=["{} {} DEFAULT {}".format(attrNameKeyItem,
+                                                edgeAttrTypeDefaultDict[attrNameKeyItem]["type"],
+                                                edgeAttrTypeDefaultDict[attrNameKeyItem]["default"]) for attrNameKeyItem in edgeAttrTypeDefaultDict[tagTypeItem]]
+        attrListStr=",".join(attrList)
+        gClient.execute_query("CREATE EDGE IF NOT EXISTS {} ({})".format(tagTypeItem,attrListStr))
+
 if __name__=="__main__":
     
-    srcGHost=""
+    srcGHost="9.135.95.249"
     srcGPort=13708
     srcGUser="root"
     srcGPassword="nebula"
-    srcGdbName="company_product_field_musklin"
+    srcGdbName="post_dept_char_major_skill__wliangwang"
     
-    srcConnection_pool = ConnectionPool(srcGHost, srcGPort,network_timeout=300000)
-    srcClient = GraphClient(srcConnection_pool)
-    srcClient.authenticate(srcGUser, srcGPassword)
-    srcClient.execute_query("use {}".format(srcGdbName))
+    # srcConnection_pool = ConnectionPool(srcGHost, srcGPort,network_timeout=300000)
+    # srcClient = GraphClient(srcConnection_pool)
+    # srcClient.authenticate(srcGUser, srcGPassword)
+    # srcClient.execute_query("use {}".format(srcGdbName))
     
     # start=time.time()
     # adf=wrapNebula2Df(srcClient.execute_query("LOOKUP ON Token WHERE Token.TokenName=='深'|GO FROM $-.VertexID OVER consistOf REVERSELY YIELD consistOf._dst AS tailSysId,$$.Company.CompanyName AS CompanyName,consistOf.weight AS weight|    ORDER BY $-.weight DESC|LIMIT 50 UNION \
@@ -442,33 +479,35 @@ if __name__=="__main__":
     
     # print(adf.head())
     
-    # srcVertexKeynameDict={
-    #     "Company":"CompanyName",
-    #     "Field":"FieldName"
-    # }
-    # edgeTypeList=["belongTo"]
+    srcVertexKeynameDict={
+        "Skill":"SkillName"
+    }
+    edgeTypeList=["relate"]
 
-    # tgtGHost=""
-    # tgtGPort=13708
-    # tgtGAPIUrl="http://{}:8083"
-    # tgtGUser="root"
-    # tgtGPassword="nebula"
-    # tgtGdbName="company_product_field_musklin"
+    gHost="9.135.95.249"
+    gPort=13708
+    gUser="root"
+    gPassword="nebula"
+    srcGdbName="post_dept_char_major_skill__wliangwang"
+    tgtGdbName="post_skill_school_ianxu"
+    tgtGAPIUrl="http://{}:8083".format("9.135.95.249")
     
-    # projectName="transform_some_data"
+    projectName="transfer_skills"
 
-    # batchSize=1024
-    # myDfList=[]
+    batchSize=1024
+    myDfList=[]
 
-    # csv2platoDTypeDict={
-    #     "object":"string",
-    #     "float64":"double",
-    #     "int64":"int",
-    # }
+    csv2platoDTypeDict={
+        "object":"string",
+        "float64":"double",
+        "int64":"int",
+    }
     
-    # transferBetweenPlato(srcGHost,srcGPort,srcGUser,srcGPassword,srcGdbName,
-    #                      tgtGHost,tgtGPort,tgtGUser,tgtGPassword,tgtGdbName,tgtGAPIUrl,
-    #                      edgeTypeList=[],
-    #                      srcVertexKeynameDict=srcVertexKeynameDict,csv2platoDTypeDict=csv2platoDTypeDict)
+    transferBetweenPlato(gHost,gPort,gUser,gPassword,
+                         srcGdbName,tgtGdbName,tgtGAPIUrl,
+                         edgeTypeList=edgeTypeList,
+                         srcVertexKeynameDict=srcVertexKeynameDict,
+                         csv2platoDTypeDict=csv2platoDTypeDict,
+                         projectName=projectName)
     
     # pass
