@@ -20,10 +20,11 @@ def buildVertex(vertexJson,graphClient,nodeSysIDUUID=True):
         vertexDf=pd.read_csv(vertexPath)
         
         gNodeAttrDf=wrapNebula2Df(graphClient.execute_query("DESCRIBE TAG {}".format(nodeType)))
+        
+        attrTypeList=[]
         if gNodeAttrDf.shape[0]>0:
             gNodeAttrList=gNodeAttrDf["Field"].values.flatten().tolist()
             
-            attrTypeList=[]
             for attrKeyItem in csv_attr2type_map:
                 if attrKeyItem in  csv2plato_attr_map and csv2plato_attr_map[attrKeyItem] in gNodeAttrList:
                     if attrKeyItem==idCol:
@@ -91,20 +92,22 @@ def buildEdge(edgeJson,graphClient,srcSysIDUUID=True,tgtSysIDUUID=True):
         csv_attr2type_map=edgeInfoItem["attr_type_map"]
         edgeDf=pd.read_csv(edgePath)
         
-        gEdgeAttrList=wrapNebula2Df(graphClient.execute_query("DESCRIBE EDGE {}".format(edgeType)))["Field"].values.flatten().tolist()
+        gEdgeAttrDf=wrapNebula2Df(graphClient.execute_query("DESCRIBE EDGE {}".format(edgeType)))
         
         attrTypeList=[]
-        for attrKeyItem in csv_attr2type_map:
-            if attrKeyItem in  csv2plato_attr_map and csv2plato_attr_map[attrKeyItem] in gEdgeAttrList:
-                if pdPlatoTypeSame(edgeDf[attrKeyItem],csv_attr2type_map[attrKeyItem]):
-                    attrTypeList.append({
-                            "name": csv2plato_attr_map[attrKeyItem],
-                            "type": csv_attr2type_map[attrKeyItem],
-                            "index": list(edgeDf.columns).index(attrKeyItem)
-                        })
-                else:
-                    raise TypeError("csv({}_{})与uploadSchema.json类型冲突，请核查".format(edgePath.split("/")[-1],
-                                                                                            attrKeyItem))
+        if gEdgeAttrDf.shape[0]>0:
+            gEdgeAttrList=gEdgeAttrDf["Field"].values.flatten().tolist()
+            for attrKeyItem in csv_attr2type_map:
+                if attrKeyItem in  csv2plato_attr_map and csv2plato_attr_map[attrKeyItem] in gEdgeAttrList:
+                    if pdPlatoTypeSame(edgeDf[attrKeyItem],csv_attr2type_map[attrKeyItem]):
+                        attrTypeList.append({
+                                "name": csv2plato_attr_map[attrKeyItem],
+                                "type": csv_attr2type_map[attrKeyItem],
+                                "index": list(edgeDf.columns).index(attrKeyItem)
+                            })
+                    else:
+                        raise TypeError("csv({}_{})与uploadSchema.json类型冲突，请核查".format(edgePath.split("/")[-1],
+                                                                                                attrKeyItem))
 
         srcVIDDict={"function": "uuid"} if srcSysIDUUID else {}
         tgtVIDDict={"function": "uuid"} if tgtSysIDUUID else {}
@@ -195,7 +198,7 @@ def createSchemaFromSchemaJson(schemaJson,graphClient):
     return createTagErrCode,createTagIndexErrCode,rebuildTagIndexErrCode,createEdgeErrCode
             
 
-def submitSchema(schemaJson,gUrl="http://9.135.95.249:7001"):
+def submitSchema(schemaJson,gUrl="http://9.135.95.249:7001",cookie=""):
 
     url = gUrl+"/api-import/submit"
 
@@ -208,7 +211,7 @@ def submitSchema(schemaJson,gUrl="http://9.135.95.249:7001"):
         'Origin': gUrl,
         'Referer': '{}/import'.format(gUrl),
         'Accept-Language': 'zh-CN,zh;q=0.9,en;q=0.8,en-GB;q=0.7,en-US;q=0.6',
-        'Cookie': '_ga=GA1.1.599074290.1616395720; locale=ZH_CN; Hm_lvt_b9cb5b394fd669583c13f8975ca64ff0=1627524967,1627612772,1627879099,1627959086; nsid=de94b8d118e557ff3e54875946395226; nh=9.135.95.249:13708; nu=root; np=nebula; _gid=GA1.1.1256907028.1628059656; Hm_lpvt_b9cb5b394fd669583c13f8975ca64ff0=1628063018'
+        'Cookie': cookie
     }
 
     response = requests.request("POST", url, headers=headers, data=data)
